MessageSource class abstract

Pluggable message source for #{key} expressions D08.

Implementers

Constructors

MessageSource()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(String key, {String? locale, List args}) String?
Resolve a message key, optionally with locale and positional arguments. Returns null if the key is not found.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited