Dialect class abstract
Named bundle of processors + filters D10.
- Implementers
Constructors
- Dialect()
Properties
-
filters
→ Map<
String, Function> -
Filters contributed by this dialect. Defaults to empty.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Human-readable dialect name (e.g. 'Standard', 'Markdown').
no setter
-
processors
→ List<
Processor> -
Processors contributed by this dialect.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited