MapLoader class final
In-memory template loader for testing. Templates keyed by name.
- Implemented types
Properties
Methods
-
listTemplates(
) → List< String> - Return all template names stored in this loader.
-
load(
String name) → Future< String> -
Load a template asynchronously.
override
-
loadSync(
String name) → String? -
Load a template synchronously, if supported.
Returns null only when sync loading is unsupported by the loader.
Implementations that support sync loading should throw
TemplateNotFoundException-compatible errors when a template is missing.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited